@@ -3,10 +3,11 @@ from unidecode import unidecode
 
 from take_text_preprocess.presentation import pre_process
 
-from weak_postagger.logic.utils import get_class_name_from_file
+from weak_postagger.logic.utils import get_class_name_from_file, replace_abbreviations
 from weak_postagger.data.read_word_files import read_file, get_files_in_dir
 from weak_postagger.logic.param import CLASS_TO_POS_TAG, PUNCTUATION, SYMBOLS, \
     SUBSTANTIVE_PLACEHOLDERS, NUMERIC_PLACEHOLDERS, OOV_TOKEN
+from weak_postagger.logic.abbreviations import ABBREVIATIONS
 
 
 class ListWeakModel:
@@ -54,6 +55,7 @@ class ListWeakModel:
         self.__symbols = SYMBOLS
         self.__substantive_placeholder = SUBSTANTIVE_PLACEHOLDERS
         self.__numeric_placeholder = NUMERIC_PLACEHOLDERS
+        self.__abbreviations_dict = ABBREVIATIONS
         
         self.__generate_words_per_class_dict()
         self.__generate_vocabulary()
@@ -93,6 +95,7 @@ class ListWeakModel:
             split_sentence = sentence.split()
         
         sentence_labels = []
+        split_sentence = replace_abbreviations(split_sentence, self.__abbreviations_dict)
         
         for index, word in enumerate(split_sentence):
             sentence_labels.append(self.vocabulary.get(word,
@@ -159,7 +162,7 @@ class ListWeakModel:
         self.__update_vocab_by_list(self.__punctuation, 'PON')
         self.__update_vocab_by_list(self.__symbols, 'SIMB')
         self.__update_vocab_by_list(self.__substantive_placeholder, 'SUBS')
-        self.__update_vocab_by_list(self.__numeric_placeholder, 'NUMB')
+        self.__update_vocab_by_list(self.__numeric_placeholder, 'NUM')
         self.__update_vocab_by_list(['LAUGH'], 'INT')
         
         self.vocabulary = {key: sorted(list(set(value))) for key, value in self.vocabulary.items()}
