@@ -20,7 +20,7 @@ def get_class_name_from_file(file_name: str) -> str:
 def replace_abbreviations(sentence: tp.List[str], abbreviations: tp.Dict[str, str]) -> tp.List[str]:
     """
         Checks if there is abbreviated words on the sentence and replaces it with the full word.
-        
+
     :param sentence: Sentence to be processed.
     :type sentence: `str`
     :param abbreviations: Dictionary containing word abbreviations and their full form.
@@ -28,7 +28,10 @@ def replace_abbreviations(sentence: tp.List[str], abbreviations: tp.Dict[str, st
     :return: Sentence with all words in their full form.
     :rtype: `tp.List[str]`
     """
-    for ind, word in enumerate(sentence):
+    modified_sentence = []
+    for word in sentence:
         if word in abbreviations:
-            sentence[ind] = abbreviations[word]
-    return sentence
+            modified_sentence += abbreviations[word].split()
+        else:
+            modified_sentence += [word]
+    return modified_sentence
